Class: Google::Shopping::Merchant::Products::V1beta::Product

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/products/v1beta/products.rb

Overview

The processed product, built from multiple [product inputs][google.shopping.merchant.products.v1main.ProductInput] after applying rules and supplemental data sources. This processed product matches what is shown in your Merchant Center account. Each product is built from exactly one primary data source product input, and multiple supplemental data source inputs. After inserting, updating, or deleting a product input, it may take several minutes before the updated processed product can be retrieved.

All fields in the processed product and its sub-messages match the name of their corresponding attribute in the Product data specification with some exceptions.

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Google::Shopping::Merchant::Products::V1beta::Attributes (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#automated_discounts::Google::Shopping::Merchant::Products::V1beta::AutomatedDiscounts (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#channel::Google::Shopping::Type::Channel::ChannelEnum (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#content_language::String (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_attributes::Array<::Google::Shopping::Type::CustomAttribute> (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_source::String (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#feed_label::String (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#offer_id::String (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product_status::Google::Shopping::Merchant::Products::V1beta::ProductStatus (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#version_number::Integer (readonly)



107
108
109
110
# File 'proto_docs/google/shopping/merchant/products/v1beta/products.rb', line 107

class Product
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end